@@ -2,7 +2,7 @@ package Catmandu::Store::ElasticSearch;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.05';
 
 use Moo;
 use Search::Elasticsearch;
@@ -10,12 +10,13 @@ use Catmandu::Store::ElasticSearch::Bag;
 use namespace::clean;
 
 with 'Catmandu::Store';
+with 'Catmandu::Droppable';
 
-has index_name     => (is => 'ro', required => 1);
+has index_name => (is => 'ro', required => 1);
 has index_settings => (is => 'ro', lazy => 1, default => sub { +{} });
 has index_mappings => (is => 'ro', lazy => 1, default => sub { +{} });
-has _es_args       => (is => 'rw', lazy => 1, default => sub { +{} });
-has es             => (is => 'lazy');
+has _es_args => (is => 'rw', lazy => 1, default => sub { +{} });
+has es => (is => 'lazy');
 
 sub _build_es {
     my ($self) = @_;
@@ -157,6 +158,40 @@ this may fail until this class is reinstantiated, creating a new index.
 
 This store expects version 1.0 or higher of the Elasticsearch server.
 
+Note that Elasticsearch >= 2.0 doesn't like keys that start with an underscore such as
+C<_id>. You can use the C<key_prefix> option at store level or C<id_prefix> at
+bag level to handle this.
+
+    # in your catmandu.yml
+    store:
+      yourstore:
+        package: ElasticSearch
+        options:
+          # use my_id instead of _id
+          key_prefix: my_
+
+If you want to use the C<delete_by_query> method with Elasticsearch >= 2.0 you
+will have to L<install the delete by query plugin|https://www.elastic.co/guide/en/elasticsearch/plugins/current/plugins-delete-by-query.html>.
+
+=head1 MIGRATING A STORE FROM ELASTICSEARCH 1.0 TO 2.0 OR HIGHER
+
+1. backup your data as JSON
+
+    catmandu export yourstore --bag yourbag to --file /path/to/yourbag.json -v
+
+2. drop the store
+
+    catmandu drop yourstore
+
+3. upgrade the Elasticsearch server
+
+4. update your catmandu.yml with a C<key_prefix> or C<id_prefix> (see COMPATIBILITY)
+
+5. import your data using the new keys specified in your catmandu.yml
+
+    catmandu import --file /path/to/yourbag.json --fix 'move_field(_id, my_id)' \
+    to yourstore --bag yourbag -v
+
 =head1 ERROR HANDLING
 
 Error handling can be activated by specifying an error handling callback for index when creating
@@ -168,7 +203,7 @@ a store. E.g. to create an error handler for the bag 'data' index use:
                  });
 
     sub error_handler {
-        my ($action,$response,$i) = @_;
+        my ($action, $response, $i) = @_;
     }
 
 =head1 SEE ALSO
