@@ -2,7 +2,7 @@ package Catmandu::Store::ElasticSearch::Bag;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.05';
 
 use Moo;
 use Catmandu::Hits;
@@ -10,6 +10,7 @@ use Catmandu::Store::ElasticSearch::Searcher;
 use Catmandu::Store::ElasticSearch::CQL;
 
 with 'Catmandu::Bag';
+with 'Catmandu::Droppable';
 with 'Catmandu::Searchable';
 
 has buffer_size => (is => 'ro', lazy => 1, builder => 'default_buffer_size');
@@ -61,7 +62,7 @@ sub count {
     )->{count};
 }
 
-sub get { # TODO ignore missing
+sub get {
     my ($self, $id) = @_;
     try {
         $self->store->es->get_source(
@@ -76,8 +77,10 @@ sub get { # TODO ignore missing
 
 sub add {
     my ($self, $data) = @_;
+    $data = {%$data};
+    my $id = $data->{$self->id_key};
     $self->_bulk->index({
-        id     => $data->{_id},
+        id     => $id,
         source => $data,
     });
 }
@@ -87,38 +90,64 @@ sub delete {
     $self->_bulk->delete({id => $id});
 }
 
-sub delete_all { # TODO refresh
+sub delete_all {
     my ($self) = @_;
     my $es = $self->store->es;
-    $es->delete_by_query(
-        index => $self->store->index_name,
-        type  => $self->name,
-        body  => {
-            query => {match_all => {}},
-        },
-    );
+    if ($es->can('delete_by_query')) {
+        $es->delete_by_query(
+            index => $self->store->index_name,
+            type => $self->name,
+            body => {
+                query => {match_all => {}},
+            },
+        );
+    } else { # TODO document plugin needed for es >= 2.0
+        $es->transport->perform_request(
+            method => 'DELETE',
+            path => '/'.$self->store->index_name.'/'.$self->name.'/_query',
+            body => {
+                query => {match_all => {}},
+            }
+        );
+    }
 }
 
-sub delete_by_query { # TODO refresh
+sub delete_by_query {
     my ($self, %args) = @_;
     my $es = $self->store->es;
-    $es->delete_by_query(
-        index => $self->store->index_name,
-        type  => $self->name,
-        body  => {
-            query => $args{query},
-        },
-    );
+    if ($es->can('delete_by_query')) {
+        $es->delete_by_query(
+            index => $self->store->index_name,
+            type => $self->name,
+            body => {
+                query => $args{query},
+            },
+        );
+    } else { # TODO document plugin needed for es >= 2.0
+        $es->transport->perform_request(
+            method => 'DELETE',
+            path => '/'.$self->store->index_name.'/'.$self->name.'/_query',
+            body => {
+                query => $args{query},
+            }
+        );
+    }
 }
 
 sub commit {
     my ($self) = @_;
     $self->_bulk->flush;
+    $self->store->es->transport->perform_request(
+        method => 'POST',
+        path => '/'.$self->store->index_name.'/_refresh',
+    );
 }
 
 sub search {
     my ($self, %args) = @_;
 
+    my $id_key = $self->id_key;
+
     my $start = delete $args{start};
     my $limit = delete $args{limit};
     my $bag   = delete $args{reify};
@@ -146,9 +175,9 @@ sub search {
     };
 
     if ($bag) {
-        $hits->{hits} = [ map { $bag->get($_->{_id}) } @$docs ];
+        $hits->{hits} = [ map { $bag->get($_->{$id_key}) } @$docs ];
     } elsif ($args{fields}) {
-        $hits->{hits} = [ map { $_->{fields} || {} } @$docs ];
+        $hits->{hits} = [ map { $_->{fields} || +{} } @$docs ];
     } else {
         $hits->{hits} = [ map { $_->{_source} } @$docs ];
     }
@@ -162,7 +191,7 @@ sub search {
     if ($args{highlight}) {
         for my $hit (@$docs) {
             if (my $hl = $hit->{highlight}) {
-                $hits->{highlight}{$hit->{_id}} = $hl;
+                $hits->{highlight}{$hit->{$id_key}} = $hl;
             }
         }
     }
@@ -204,7 +233,8 @@ sub _translate_sru_sortkey {
 
 sub translate_cql_query {
     my ($self, $query) = @_;
-    Catmandu::Store::ElasticSearch::CQL->new(mapping => $self->cql_mapping)->parse($query);
+    Catmandu::Store::ElasticSearch::CQL->new(mapping => $self->cql_mapping,
+        id_key => $self->id_key)->parse($query);
 }
 
 sub normalize_query {
