@@ -2,7 +2,7 @@ package Catmandu::Store::ElasticSearch::Searcher;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.05';
 
 use Moo;
 use namespace::clean;
@@ -18,6 +18,7 @@ has sort  => (is => 'ro');
 
 sub generator {
     my ($self) = @_;
+    my $store = $self->bag->store;
     sub {
         state $total = $self->total;
         if (defined $total) {
@@ -27,8 +28,8 @@ sub generator {
         state $scroll = do {
             my $body = {query => $self->query};
             $body->{sort} = $self->sort if $self->sort;
-            $self->bag->store->es->scroll_helper(
-                index       => $self->bag->store->index_name,
+            $store->es->scroll_helper(
+                index       => $store->index_name,
                 type        => $self->bag->name,
                 search_type => $self->sort ? 'query_then_fetch' : 'scan',
                 from        => $self->start,
